//
// Tizen Native SDK
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Flora License, Version 1.1 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://floralicense.org/license/
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an AS IS BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

#ifndef _MAIN_FORM_H_
#define _MAIN_FORM_H_

#include <FBase.h>
#include <FUi.h>
#include <FNet.h>
#include "ReadForm.h"
#include "WriteForm.h"

class MainForm
	: public Tizen::Ui::Controls::Form
	, public Tizen::Ui::Controls::IFormBackEventListener
	, public Tizen::Ui::IActionEventListener
	, public Tizen::Net::Nfc::INfcManagerEventListener
	, public Tizen::Net::Nfc::INfcTagDiscoveryEventListener
	, public Tizen::Net::Nfc::INdefMessageDiscoveryEventListener
	, public Tizen::Net::Nfc::INdefTagConnectionListener
	, public Tizen::Ui::Scenes::ISceneEventListener
	, public Tizen::Base::Runtime::ITimerEventListener
{

public:
	MainForm(void);
	virtual ~MainForm(void);
	bool Initialize(void);

public:
	virtual result OnInitializing(void);
	virtual result OnTerminating(void);
	void LoadReadForm(Tizen::Net::Nfc::NdefMessage* pMsg);
	void LoadWriteForm(void);
	virtual void OnActionPerformed(const Tizen::Ui::Control& source, int actionId);
	virtual void OnFormBackRequested(Tizen::Ui::Controls::Form& source);
	virtual void OnNfcActivated(result r);
	virtual void OnNfcDeactivated(result r);
	virtual void OnNfcTagDetectedN(Tizen::Net::Nfc::TagConnection* pConnection);
	virtual void OnNfcTagLost(void);
	virtual void OnNdefMessageDetectedN(Tizen::Net::Nfc::NdefMessage* pMessage);
	virtual void OnNdefReadCompletedN(Tizen::Net::Nfc::NdefMessage* pMessage, result r);
	virtual void OnNdefWriteCompleted(result r);
	virtual void OnSceneActivatedN(const Tizen::Ui::Scenes::SceneId& previousSceneId,
								   const Tizen::Ui::Scenes::SceneId& currentSceneId, Tizen::Base::Collection::IList* pArgs);
	virtual void OnSceneDeactivated(const Tizen::Ui::Scenes::SceneId& currentSceneId,
									const Tizen::Ui::Scenes::SceneId& nextSceneId);
	virtual void OnTimerExpired(Tizen::Base::Runtime::Timer& timer);
	void WriteData(Tizen::Net::Nfc::NdefMessage* input);
	void InitializePopups(void);
	void ShowTimerPopup(const Tizen::Base::String& title, const Tizen::Base::String& message);
	void ShowOkPopup(const Tizen::Base::String& title, const Tizen::Base::String& message);
	void HideOkPopup(void);

public:
	static const RequestId REQUEST_MAINFORM = 200;
	static const RequestId REQUEST_READFORM = 201;
	static const RequestId REQUEST_WRITEDATA = 202;

protected:
	static const int ID_ACTIVATE = 101;
	static const int ID_WRITE_MEMO = 102;
	static const int ID_READ_MEMO = 103;
	static const int ID_OK = 104;
	static const int POPUP_TIMEOUT = 2000;

private:
	Tizen::Ui::Controls::FooterItem __leftFooterItem;
	Tizen::Ui::Controls::FooterItem __middleFooterItem;
	Tizen::Ui::Controls::FooterItem __rightFooterItem;
	Tizen::Ui::Controls::Label* __pTagStatus;
	ReadForm* __pReadForm;
	WriteForm* __pWriteForm;
	Tizen::Net::Nfc::NfcManager* __pNfcManager;
	Tizen::Net::Nfc::NdefTagConnection* __pNdefTagConnection;
	Tizen::Ui::Controls::Popup* __pTimerPopup;
	Tizen::Ui::Controls::Popup* __pOkPopup;
	Tizen::Ui::Controls::Label* __pTimerPopupLabel;
	Tizen::Ui::Controls::Label* __pOkPopupLabel;
	Tizen::Base::Runtime::Timer __popupTimer;
};

#endif  //_MAIN_FORM_H_
