//
// Tizen Native SDK
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Flora License, Version 1.1 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://floralicense.org/license/
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an AS IS BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

#include <new>
#include <FNet.h>
#include "NfcMemoTag.h"
#include "MainForm.h"
#include "FormFactory.h"

using namespace Tizen::App;
using namespace Tizen::Base;
using namespace Tizen::Base::Collection;
using namespace Tizen::Net::Nfc;
using namespace Tizen::System;
using namespace Tizen::Ui;
using namespace Tizen::Ui::Controls;
using namespace Tizen::Ui::Scenes;

NfcMemoTag::NfcMemoTag()
	: __isSceneRegistered(false)
{
}

NfcMemoTag::~NfcMemoTag()
{
}

Application*
NfcMemoTag::CreateInstance(void)
{
	// Create the instance through the constructor.
	return new (std::nothrow) NfcMemoTag();
}

bool
NfcMemoTag::OnAppInitializing(AppRegistry& appRegistry)
{
	// TODO:
	// Initialize UI resources and application specific data.
	// The application's permanent data and context can be obtained from the appRegistry.
	//
	// If this method is successful, return true; otherwise, return false.
	// If this method returns false, the application will be terminated.

	// Uncomment the following statement to listen to the screen on/off events.
	//PowerManager::SetScreenEventListener(*this);
	AppManager::GetInstance()->SetAppLaunchConditionEventListener(this);

	return true;
}

bool
NfcMemoTag::OnAppInitialized(void)
{
	Frame* pFrame = new Frame();

	SceneManager* pSceneManager = SceneManager::GetInstance();
	AppAssert(pSceneManager);
	static FormFactory formFactory;

	if (!__isSceneRegistered)
	{
		pFrame->Construct();
		pFrame->SetName(L"NfcMemoTag");
		AddFrame(*pFrame);

		pSceneManager->RegisterFormFactory(formFactory);
		pSceneManager->RegisterScene(L"MainScene", L"MainForm", L"");
		pSceneManager->RegisterScene(L"ReadScene", L"ReadForm", L"");
		pSceneManager->RegisterScene(L"WriteScene", L"WriteForm", L"");

		if (pSceneManager->GoForward(ForwardSceneTransition(L"MainScene")) != E_SUCCESS)
		{
			return false;
		}

		__isSceneRegistered = true;
	}
	//Disables the launch popup message by Conditional NFC App Launch.
	NfcManager::SetLaunchPopupEnabled(false);

	return true;
}

bool
NfcMemoTag::OnAppTerminating(AppRegistry& appRegistry, bool forcedTermination)
{
	return true;
}

void
NfcMemoTag::OnForeground(void)
{
}

void
NfcMemoTag::OnBackground(void)
{
}

void
NfcMemoTag::OnLowMemory(void)
{
}

void
NfcMemoTag::OnBatteryLevelChanged(BatteryLevel batteryLevel)
{
}

void
NfcMemoTag::OnScreenOn(void)
{
}

void
NfcMemoTag::OnScreenOff(void)
{
}

void
NfcMemoTag::OnAppLaunchConditionMetN(const Tizen::Base::String& condition, Tizen::Base::Object* pExtraData,
			Tizen::Base::Collection::IList* pArguments)
{
	if(!__isSceneRegistered)
	{
		Frame* pFrame = new Frame();
		pFrame->Construct();
		pFrame->SetName(L"NfcMemoTag");
		AddFrame(*pFrame);

		SceneManager* pSceneManager = SceneManager::GetInstance();
		AppAssert(pSceneManager);
		static FormFactory formFactory;
		ArrayList* pParams = null;

		pSceneManager->RegisterFormFactory(formFactory);
		pSceneManager->RegisterScene(L"MainScene", L"MainForm", L"");
		pSceneManager->RegisterScene(L"ReadScene", L"ReadForm", L"");
		pSceneManager->RegisterScene(L"WriteScene", L"WriteForm", L"");

		pParams = new (std::nothrow) ArrayList();
		NdefMessage* pMsg = NfcManager::GetCachedNdefMessageN();

		pParams->Add(*pMsg);

		pSceneManager->GoForward(ForwardSceneTransition(L"ReadScene"), pParams);

		__isSceneRegistered = true;
	}
}
