//
// Tizen Native SDK
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Flora License, Version 1.1 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://floralicense.org/license/
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an AS IS BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

#include <new>
#include "AppResourceId.h"
#include "MainForm.h"
#include "WriteForm.h"
#include <FApp.h>
#include <FGraphics.h>
#include <FText.h>

using namespace Tizen::Base;
using namespace Tizen::Base::Collection;
using namespace Tizen::Ui;
using namespace Tizen::Ui::Controls;
using namespace Tizen::Ui::Scenes;
using namespace Tizen::App;
using namespace Tizen::Graphics;
using namespace Tizen::Text;
using namespace Tizen::Net::Nfc;

WriteForm::WriteForm(void)
	: __pPayloadField(null)
{

}

WriteForm::~WriteForm(void)
{
}

bool
WriteForm::Initialize(void)
{
	Form::Construct(IDF_WRITEFORM);

	return true;
}

result
WriteForm::OnInitializing(void)
{
	result r = E_SUCCESS;
	SetName(L"WriteForm");
	Header* pHeader = GetHeader();
	pHeader->AddActionEventListener(*this);

	FooterItem writeItem;
	FooterItem cancelItem;
	Footer* pFooter = GetFooter();
	pFooter->SetShowState(true);
	pFooter->SetStyle(FOOTER_STYLE_BUTTON_TEXT);

	writeItem.Construct(ID_WRITE);
	writeItem.SetText("Write");

	pFooter->AddItem(writeItem);

	SetFormBackEventListener(this);
	pFooter->AddActionEventListener(*this);

	__pPayloadField = static_cast< EditArea* >(GetControl(IDC_EDITAREA, true));
	if (__pPayloadField == null)
	{
		AppLog("Error in getting handle to editarea __pPayloadField");
		r = E_FAILURE;
	}
	else
	{
		__pPayloadField->SetOverlayKeypadCommandButtonVisible(false);
		__pPayloadField->SetFocus();
	}

	return r;
}

result
WriteForm::OnTerminating(void)
{
	result r = E_SUCCESS;

	// TODO: Add your termination code here

	return r;
}

void
WriteForm::OnFormBackRequested(Tizen::Ui::Controls::Form& source)
{
	SceneManager* pSceneManager = SceneManager::GetInstance();
	AppAssert(pSceneManager);

	pSceneManager->GoBackward(BackwardSceneTransition());
}

void
WriteForm::OnActionPerformed(const Control& source, int actionId)
{
	SceneManager* pSceneManager = SceneManager::GetInstance();
	AppAssert(pSceneManager);

	switch (actionId)
	{
	case ID_WRITE:
		if (__pPayloadField->GetTextLength() >= 0)
		{
			ArrayList* pParams = null;
			AppLog("Write Button Pressed");

			NdefMessage* pMsg = MakeTextRecordN(__pPayloadField->GetText());
			__pPayloadField->Clear();
			pParams = new (std::nothrow) ArrayList();
			pParams->Add(*pMsg);
			pSceneManager->GoBackward(BackwardSceneTransition(), pParams);
		}
		else
		{
			AppLog("There is nothing write");
		}

		break;

	default:
		break;
	}
}

NdefMessage*
WriteForm::MakeTextRecordN(String data)
{

	//Encoding Type as English
	String encType(L"en");
	String strPayload;
	strPayload.Insert(encType.GetLength(), 0);
	strPayload += encType;
	strPayload += data;


	ByteBuffer* pPayload = Tizen::Base::Utility::StringUtil::StringToUtf8N(strPayload);
	pPayload->SetByte(0, (byte) encType.GetLength());

	//create NDEFMessage
	NdefMessage* pMsg = new (std::nothrow) NdefMessage();

	//Create RecordType, NDEF well known format messages
	NdefRecordType recordType(NDEF_TNF_WELL_KNOWN);

	//Set RecordType as Text
	recordType.SetName(NFC_NDEF_RTD_TEXT);

	//Create record
	NdefRecord* pRecord = new (std::nothrow) NdefRecord(recordType);

	//Set RecordType
	pRecord->SetRecordType(recordType);

	//Set Record Payload ID
	pRecord->SetPayloadId(L"1");

	//Set Payload
	pRecord->SetPayload(*pPayload);

	//Append Record to Message
	pMsg->AppendRecord(*pRecord);

	delete pPayload;
	return pMsg;
}
